# coding: utf-8

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from crypticorn.dex.client.models.website import Website
from typing import Set
from typing_extensions import Self


class Info(BaseModel):
    """
    Info
    """  # noqa: E501

    image_url: Optional[StrictStr] = None
    header: Optional[StrictStr] = None
    open_graph: Optional[StrictStr] = None
    websites: Optional[List[Website]] = Field(
        default=None, description="List of related websites"
    )
    __properties: ClassVar[List[str]] = [
        "image_url",
        "header",
        "open_graph",
        "websites",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Info from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in websites (list)
        _items = []
        if self.websites:
            for _item_websites in self.websites:
                if _item_websites:
                    _items.append(_item_websites.to_dict())
            _dict["websites"] = _items
        # set to None if image_url (nullable) is None
        # and model_fields_set contains the field
        if self.image_url is None and "image_url" in self.model_fields_set:
            _dict["image_url"] = None

        # set to None if header (nullable) is None
        # and model_fields_set contains the field
        if self.header is None and "header" in self.model_fields_set:
            _dict["header"] = None

        # set to None if open_graph (nullable) is None
        # and model_fields_set contains the field
        if self.open_graph is None and "open_graph" in self.model_fields_set:
            _dict["open_graph"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Info from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "image_url": obj.get("image_url"),
                "header": obj.get("header"),
                "open_graph": obj.get("open_graph"),
                "websites": [Website.from_dict(_item) for _item in obj["websites"]]
                if obj.get("websites") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa
"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from crypticorn.dex.client.models.error_response import ErrorResponse
from crypticorn.dex.client.models.info import Info
from crypticorn.dex.client.models.liquidity import Liquidity
from crypticorn.dex.client.models.paginated_response_signal_with_token import (
    PaginatedResponseSignalWithToken,
)
from crypticorn.dex.client.models.price_change import PriceChange
from crypticorn.dex.client.models.signal_overview_stats import SignalOverviewStats
from crypticorn.dex.client.models.signal_with_token import SignalWithToken
from crypticorn.dex.client.models.token import Token
from crypticorn.dex.client.models.token_data import TokenData
from crypticorn.dex.client.models.txn_counts import TxnCounts
from crypticorn.dex.client.models.txns import Txns
from crypticorn.dex.client.models.volume import Volume
from crypticorn.dex.client.models.website import Website



# coding: utf-8

"""
Indicator API

API for Indicator Data about the crypto market

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from asgiref.sync import async_to_sync
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union, Awaitable
from typing_extensions import Annotated

from crypticorn.indicator.client.models.polymarket_prediction import (
    PolymarketPrediction,
)
from crypticorn.indicator.client.models.prediction import Prediction
from crypticorn.indicator.client.models.prediction_create import PredictionCreate

from crypticorn.indicator.client.api_client import ApiClient, RequestSerialized
from crypticorn.indicator.client.api_response import ApiResponse
from crypticorn.indicator.client.rest import RESTResponseType


class PredictionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None, is_sync: bool = False) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client
        self.is_sync = is_sync

    @validate_call
    def get_latest_polymarket_predictions(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[List[PolymarketPrediction], Awaitable[List[PolymarketPrediction]]]:
        """Get Latest Polymarket Predictions"""
        if self.is_sync:
            return self._get_latest_polymarket_predictions_sync(
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_latest_polymarket_predictions_async(
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def get_latest_polymarket_predictions_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[
        ApiResponse[List[PolymarketPrediction]],
        Awaitable[ApiResponse[List[PolymarketPrediction]]],
    ]:
        """Get Latest Polymarket Predictions with HTTP info"""
        if self.is_sync:
            return self._get_latest_polymarket_predictions_sync_with_http_info(
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_latest_polymarket_predictions_async_with_http_info(
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def get_latest_polymarket_predictions_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[RESTResponseType, Awaitable[RESTResponseType]]:
        """Get Latest Polymarket Predictions without preloading content"""
        if self.is_sync:
            return self._get_latest_polymarket_predictions_sync_without_preload_content(
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return (
                self._get_latest_polymarket_predictions_async_without_preload_content(
                    _request_timeout=_request_timeout,
                    _request_auth=_request_auth,
                    _content_type=_content_type,
                    _headers=_headers,
                    _host_index=_host_index,
                )
            )

    # Private async implementation methods
    @validate_call
    async def _get_latest_polymarket_predictions_async(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[PolymarketPrediction]:
        """Get Latest Polymarket Predictions

        Get the latest Polymarket predictions for all symbols and intervals.  The response contains one latest prediction per (symbol, interval) pair.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_latest_polymarket_predictions_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[PolymarketPrediction]",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def _get_latest_polymarket_predictions_async_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[PolymarketPrediction]]:
        """Get Latest Polymarket Predictions

        Get the latest Polymarket predictions for all symbols and intervals.  The response contains one latest prediction per (symbol, interval) pair.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_latest_polymarket_predictions_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[PolymarketPrediction]",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data, response_types_map=_response_types_map
        )

    @validate_call
    async def _get_latest_polymarket_predictions_async_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Latest Polymarket Predictions

        Get the latest Polymarket predictions for all symbols and intervals.  The response contains one latest prediction per (symbol, interval) pair.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_latest_polymarket_predictions_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[PolymarketPrediction]",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data

    # Private sync implementation methods
    @validate_call
    def _get_latest_polymarket_predictions_sync(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[PolymarketPrediction]:
        """Synchronous version of get_latest_polymarket_predictions"""
        return async_to_sync(self._get_latest_polymarket_predictions_async)(
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _get_latest_polymarket_predictions_sync_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[PolymarketPrediction]]:
        """Synchronous version of get_latest_polymarket_predictions_with_http_info"""
        return async_to_sync(
            self._get_latest_polymarket_predictions_async_with_http_info
        )(
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _get_latest_polymarket_predictions_sync_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Synchronous version of get_latest_polymarket_predictions_without_preload_content"""
        return async_to_sync(
            self._get_latest_polymarket_predictions_async_without_preload_content
        )(
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    def _get_latest_polymarket_predictions_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["APIKeyHeader", "HTTPBearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/predictions/polymarket/latest",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def get_latest_prediction(
        self,
        symbol: Annotated[
            StrictStr, Field(description="The symbol to get the latest prediction for")
        ],
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[Prediction, Awaitable[Prediction]]:
        """Get Latest Prediction"""
        if self.is_sync:
            return self._get_latest_prediction_sync(
                symbol=symbol,
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_latest_prediction_async(
                symbol=symbol,
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def get_latest_prediction_with_http_info(
        self,
        symbol: Annotated[
            StrictStr, Field(description="The symbol to get the latest prediction for")
        ],
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[ApiResponse[Prediction], Awaitable[ApiResponse[Prediction]]]:
        """Get Latest Prediction with HTTP info"""
        if self.is_sync:
            return self._get_latest_prediction_sync_with_http_info(
                symbol=symbol,
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_latest_prediction_async_with_http_info(
                symbol=symbol,
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def get_latest_prediction_without_preload_content(
        self,
        symbol: Annotated[
            StrictStr, Field(description="The symbol to get the latest prediction for")
        ],
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[RESTResponseType, Awaitable[RESTResponseType]]:
        """Get Latest Prediction without preloading content"""
        if self.is_sync:
            return self._get_latest_prediction_sync_without_preload_content(
                symbol=symbol,
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_latest_prediction_async_without_preload_content(
                symbol=symbol,
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    # Private async implementation methods
    @validate_call
    async def _get_latest_prediction_async(
        self,
        symbol: Annotated[
            StrictStr, Field(description="The symbol to get the latest prediction for")
        ],
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Prediction:
        """Get Latest Prediction

        Get the latest prediction for a given symbol and version. If no version is provided, the latest AI model version is used.

        :param symbol: The symbol to get the latest prediction for (required)
        :type symbol: str
        :param version: The version of the prediction to get. Defaults to the latest AI model version.
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_latest_prediction_serialize(
            symbol=symbol,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "Prediction",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def _get_latest_prediction_async_with_http_info(
        self,
        symbol: Annotated[
            StrictStr, Field(description="The symbol to get the latest prediction for")
        ],
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Prediction]:
        """Get Latest Prediction

        Get the latest prediction for a given symbol and version. If no version is provided, the latest AI model version is used.

        :param symbol: The symbol to get the latest prediction for (required)
        :type symbol: str
        :param version: The version of the prediction to get. Defaults to the latest AI model version.
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_latest_prediction_serialize(
            symbol=symbol,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "Prediction",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data, response_types_map=_response_types_map
        )

    @validate_call
    async def _get_latest_prediction_async_without_preload_content(
        self,
        symbol: Annotated[
            StrictStr, Field(description="The symbol to get the latest prediction for")
        ],
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Latest Prediction

        Get the latest prediction for a given symbol and version. If no version is provided, the latest AI model version is used.

        :param symbol: The symbol to get the latest prediction for (required)
        :type symbol: str
        :param version: The version of the prediction to get. Defaults to the latest AI model version.
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_latest_prediction_serialize(
            symbol=symbol,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "Prediction",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data

    # Private sync implementation methods
    @validate_call
    def _get_latest_prediction_sync(
        self,
        symbol: Annotated[
            StrictStr, Field(description="The symbol to get the latest prediction for")
        ],
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Prediction:
        """Synchronous version of get_latest_prediction"""
        return async_to_sync(self._get_latest_prediction_async)(
            symbol=symbol,
            version=version,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _get_latest_prediction_sync_with_http_info(
        self,
        symbol: Annotated[
            StrictStr, Field(description="The symbol to get the latest prediction for")
        ],
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Prediction]:
        """Synchronous version of get_latest_prediction_with_http_info"""
        return async_to_sync(self._get_latest_prediction_async_with_http_info)(
            symbol=symbol,
            version=version,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _get_latest_prediction_sync_without_preload_content(
        self,
        symbol: Annotated[
            StrictStr, Field(description="The symbol to get the latest prediction for")
        ],
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Synchronous version of get_latest_prediction_without_preload_content"""
        return async_to_sync(self._get_latest_prediction_async_without_preload_content)(
            symbol=symbol,
            version=version,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    def _get_latest_prediction_serialize(
        self,
        symbol,
        version,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if symbol is not None:
            _path_params["symbol"] = symbol
        # process the query parameters
        if version is not None:
            _query_params.append(("version", version))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["APIKeyHeader", "HTTPBearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/predictions/latest/{symbol}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def get_latest_predictions(
        self,
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[List[Prediction], Awaitable[List[Prediction]]]:
        """Get Latest Predictions"""
        if self.is_sync:
            return self._get_latest_predictions_sync(
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_latest_predictions_async(
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def get_latest_predictions_with_http_info(
        self,
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[ApiResponse[List[Prediction]], Awaitable[ApiResponse[List[Prediction]]]]:
        """Get Latest Predictions with HTTP info"""
        if self.is_sync:
            return self._get_latest_predictions_sync_with_http_info(
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_latest_predictions_async_with_http_info(
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def get_latest_predictions_without_preload_content(
        self,
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[RESTResponseType, Awaitable[RESTResponseType]]:
        """Get Latest Predictions without preloading content"""
        if self.is_sync:
            return self._get_latest_predictions_sync_without_preload_content(
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_latest_predictions_async_without_preload_content(
                version=version,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    # Private async implementation methods
    @validate_call
    async def _get_latest_predictions_async(
        self,
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Prediction]:
        """Get Latest Predictions

        Get the latest predictions for a given version for all symbols. If no version is provided, the latest AI model version is used.

        :param version: The version of the prediction to get. Defaults to the latest AI model version.
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_latest_predictions_serialize(
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[Prediction]",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def _get_latest_predictions_async_with_http_info(
        self,
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Prediction]]:
        """Get Latest Predictions

        Get the latest predictions for a given version for all symbols. If no version is provided, the latest AI model version is used.

        :param version: The version of the prediction to get. Defaults to the latest AI model version.
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_latest_predictions_serialize(
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[Prediction]",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data, response_types_map=_response_types_map
        )

    @validate_call
    async def _get_latest_predictions_async_without_preload_content(
        self,
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Latest Predictions

        Get the latest predictions for a given version for all symbols. If no version is provided, the latest AI model version is used.

        :param version: The version of the prediction to get. Defaults to the latest AI model version.
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_latest_predictions_serialize(
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[Prediction]",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data

    # Private sync implementation methods
    @validate_call
    def _get_latest_predictions_sync(
        self,
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Prediction]:
        """Synchronous version of get_latest_predictions"""
        return async_to_sync(self._get_latest_predictions_async)(
            version=version,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _get_latest_predictions_sync_with_http_info(
        self,
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Prediction]]:
        """Synchronous version of get_latest_predictions_with_http_info"""
        return async_to_sync(self._get_latest_predictions_async_with_http_info)(
            version=version,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _get_latest_predictions_sync_without_preload_content(
        self,
        version: Annotated[
            Optional[StrictStr],
            Field(
                description="The version of the prediction to get. Defaults to the latest AI model version."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Synchronous version of get_latest_predictions_without_preload_content"""
        return async_to_sync(
            self._get_latest_predictions_async_without_preload_content
        )(
            version=version,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    def _get_latest_predictions_serialize(
        self,
        version,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if version is not None:
            _query_params.append(("version", version))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["APIKeyHeader", "HTTPBearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/predictions/latest",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def post_polymarket_prediction(
        self,
        polymarket_prediction: PolymarketPrediction,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[object, Awaitable[object]]:
        """Post Polymarket Prediction"""
        if self.is_sync:
            return self._post_polymarket_prediction_sync(
                polymarket_prediction=polymarket_prediction,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._post_polymarket_prediction_async(
                polymarket_prediction=polymarket_prediction,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def post_polymarket_prediction_with_http_info(
        self,
        polymarket_prediction: PolymarketPrediction,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[ApiResponse[object], Awaitable[ApiResponse[object]]]:
        """Post Polymarket Prediction with HTTP info"""
        if self.is_sync:
            return self._post_polymarket_prediction_sync_with_http_info(
                polymarket_prediction=polymarket_prediction,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._post_polymarket_prediction_async_with_http_info(
                polymarket_prediction=polymarket_prediction,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def post_polymarket_prediction_without_preload_content(
        self,
        polymarket_prediction: PolymarketPrediction,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[RESTResponseType, Awaitable[RESTResponseType]]:
        """Post Polymarket Prediction without preloading content"""
        if self.is_sync:
            return self._post_polymarket_prediction_sync_without_preload_content(
                polymarket_prediction=polymarket_prediction,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._post_polymarket_prediction_async_without_preload_content(
                polymarket_prediction=polymarket_prediction,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    # Private async implementation methods
    @validate_call
    async def _post_polymarket_prediction_async(
        self,
        polymarket_prediction: PolymarketPrediction,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Post Polymarket Prediction

        Post a new Polymarket prediction.  The prediction is stored in the background and a 202 response is returned.

        :param polymarket_prediction: (required)
        :type polymarket_prediction: PolymarketPrediction
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._post_polymarket_prediction_serialize(
            polymarket_prediction=polymarket_prediction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "202": "object",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def _post_polymarket_prediction_async_with_http_info(
        self,
        polymarket_prediction: PolymarketPrediction,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Post Polymarket Prediction

        Post a new Polymarket prediction.  The prediction is stored in the background and a 202 response is returned.

        :param polymarket_prediction: (required)
        :type polymarket_prediction: PolymarketPrediction
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._post_polymarket_prediction_serialize(
            polymarket_prediction=polymarket_prediction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "202": "object",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data, response_types_map=_response_types_map
        )

    @validate_call
    async def _post_polymarket_prediction_async_without_preload_content(
        self,
        polymarket_prediction: PolymarketPrediction,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Post Polymarket Prediction

        Post a new Polymarket prediction.  The prediction is stored in the background and a 202 response is returned.

        :param polymarket_prediction: (required)
        :type polymarket_prediction: PolymarketPrediction
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._post_polymarket_prediction_serialize(
            polymarket_prediction=polymarket_prediction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "202": "object",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data

    # Private sync implementation methods
    @validate_call
    def _post_polymarket_prediction_sync(
        self,
        polymarket_prediction: PolymarketPrediction,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Synchronous version of post_polymarket_prediction"""
        return async_to_sync(self._post_polymarket_prediction_async)(
            polymarket_prediction=polymarket_prediction,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _post_polymarket_prediction_sync_with_http_info(
        self,
        polymarket_prediction: PolymarketPrediction,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Synchronous version of post_polymarket_prediction_with_http_info"""
        return async_to_sync(self._post_polymarket_prediction_async_with_http_info)(
            polymarket_prediction=polymarket_prediction,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _post_polymarket_prediction_sync_without_preload_content(
        self,
        polymarket_prediction: PolymarketPrediction,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Synchronous version of post_polymarket_prediction_without_preload_content"""
        return async_to_sync(
            self._post_polymarket_prediction_async_without_preload_content
        )(
            polymarket_prediction=polymarket_prediction,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    def _post_polymarket_prediction_serialize(
        self,
        polymarket_prediction,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if polymarket_prediction is not None:
            _body_params = polymarket_prediction

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["APIKeyHeader"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/predictions/polymarket",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def post_prediction(
        self,
        prediction_create: PredictionCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[object, Awaitable[object]]:
        """Post Prediction"""
        if self.is_sync:
            return self._post_prediction_sync(
                prediction_create=prediction_create,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._post_prediction_async(
                prediction_create=prediction_create,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def post_prediction_with_http_info(
        self,
        prediction_create: PredictionCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[ApiResponse[object], Awaitable[ApiResponse[object]]]:
        """Post Prediction with HTTP info"""
        if self.is_sync:
            return self._post_prediction_sync_with_http_info(
                prediction_create=prediction_create,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._post_prediction_async_with_http_info(
                prediction_create=prediction_create,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def post_prediction_without_preload_content(
        self,
        prediction_create: PredictionCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[RESTResponseType, Awaitable[RESTResponseType]]:
        """Post Prediction without preloading content"""
        if self.is_sync:
            return self._post_prediction_sync_without_preload_content(
                prediction_create=prediction_create,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._post_prediction_async_without_preload_content(
                prediction_create=prediction_create,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    # Private async implementation methods
    @validate_call
    async def _post_prediction_async(
        self,
        prediction_create: PredictionCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Post Prediction

        Post a new prediction. The prediction is processed in the background, and the response is immediately returned. Only API key authentication is supported.

        :param prediction_create: (required)
        :type prediction_create: PredictionCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._post_prediction_serialize(
            prediction_create=prediction_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "202": "object",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def _post_prediction_async_with_http_info(
        self,
        prediction_create: PredictionCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Post Prediction

        Post a new prediction. The prediction is processed in the background, and the response is immediately returned. Only API key authentication is supported.

        :param prediction_create: (required)
        :type prediction_create: PredictionCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._post_prediction_serialize(
            prediction_create=prediction_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "202": "object",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data, response_types_map=_response_types_map
        )

    @validate_call
    async def _post_prediction_async_without_preload_content(
        self,
        prediction_create: PredictionCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Post Prediction

        Post a new prediction. The prediction is processed in the background, and the response is immediately returned. Only API key authentication is supported.

        :param prediction_create: (required)
        :type prediction_create: PredictionCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._post_prediction_serialize(
            prediction_create=prediction_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "202": "object",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data

    # Private sync implementation methods
    @validate_call
    def _post_prediction_sync(
        self,
        prediction_create: PredictionCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Synchronous version of post_prediction"""
        return async_to_sync(self._post_prediction_async)(
            prediction_create=prediction_create,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _post_prediction_sync_with_http_info(
        self,
        prediction_create: PredictionCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Synchronous version of post_prediction_with_http_info"""
        return async_to_sync(self._post_prediction_async_with_http_info)(
            prediction_create=prediction_create,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _post_prediction_sync_without_preload_content(
        self,
        prediction_create: PredictionCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Synchronous version of post_prediction_without_preload_content"""
        return async_to_sync(self._post_prediction_async_without_preload_content)(
            prediction_create=prediction_create,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    def _post_prediction_serialize(
        self,
        prediction_create,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if prediction_create is not None:
            _body_params = prediction_create

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["APIKeyHeader"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/predictions",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List
from crypticorn.dex.client.models.txn_counts import TxnCounts
from typing import Optional, Set
from typing_extensions import Self


class Txns(BaseModel):
    """
    Txns
    """  # noqa: E501

    m5: TxnCounts = Field(
        description="Buy/sell transaction counts over the last 5 minutes"
    )
    h1: TxnCounts = Field(description="Buy/sell transaction counts over the last hour")
    h6: TxnCounts = Field(
        description="Buy/sell transaction counts over the last 6 hours"
    )
    h24: TxnCounts = Field(
        description="Buy/sell transaction counts over the last 24 hours"
    )
    __properties: ClassVar[List[str]] = ["m5", "h1", "h6", "h24"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Txns from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of m5
        if self.m5:
            _dict["m5"] = self.m5.to_dict()
        # override the default output from pydantic by calling `to_dict()` of h1
        if self.h1:
            _dict["h1"] = self.h1.to_dict()
        # override the default output from pydantic by calling `to_dict()` of h6
        if self.h6:
            _dict["h6"] = self.h6.to_dict()
        # override the default output from pydantic by calling `to_dict()` of h24
        if self.h24:
            _dict["h24"] = self.h24.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Txns from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "m5": TxnCounts.from_dict(obj["m5"])
                if obj.get("m5") is not None
                else None,
                "h1": TxnCounts.from_dict(obj["h1"])
                if obj.get("h1") is not None
                else None,
                "h6": TxnCounts.from_dict(obj["h6"])
                if obj.get("h6") is not None
                else None,
                "h24": TxnCounts.from_dict(obj["h24"])
                if obj.get("h24") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Trading API

API for automated trading and exchange interface. This API is used to trade on the exchange and manage bots, API keys, orders, and more.

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from crypticorn.trade.client.models.execution_ids import ExecutionIds
from typing import Optional, Set
from typing_extensions import Self


class PostFuturesAction(BaseModel):
    """
    The response when posting a futures action
    """  # noqa: E501

    id: StrictStr = Field(description="Action ID.")
    execution_ids: ExecutionIds = Field(description="Execution IDs for the action.")
    __properties: ClassVar[List[str]] = ["id", "execution_ids"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PostFuturesAction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of execution_ids
        if self.execution_ids:
            _dict["execution_ids"] = self.execution_ids.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PostFuturesAction from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "execution_ids": ExecutionIds.from_dict(obj["execution_ids"])
                if obj.get("execution_ids") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Indicator API

API for Indicator Data about the crypto market

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictFloat,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing import Any, ClassVar, Dict, List, Union
from typing import Optional, Set
from typing_extensions import Self


class PredictionCreate(BaseModel):
    """
    Prediction create model
    """  # noqa: E501

    symbol: StrictStr = Field(description="The symbol of the prediction")
    timestamp: StrictInt = Field(description="The timestamp of the prediction creation")
    version: StrictStr = Field(description="The version of the AI model")
    p10: List[Union[StrictFloat, StrictInt]] = Field(
        description="The 10th percentile of the prediction. List of 24 values in 15 minutes intervals."
    )
    p30: List[Union[StrictFloat, StrictInt]] = Field(
        description="The 30th percentile of the prediction. List of 24 values in 15 minutes intervals."
    )
    p50: List[Union[StrictFloat, StrictInt]] = Field(
        description="The 50th percentile of the prediction. List of 24 values in 15 minutes intervals."
    )
    p70: List[Union[StrictFloat, StrictInt]] = Field(
        description="The 70th percentile of the prediction. List of 24 values in 15 minutes intervals."
    )
    p90: List[Union[StrictFloat, StrictInt]] = Field(
        description="The 90th percentile of the prediction. List of 24 values in 15 minutes intervals."
    )
    __properties: ClassVar[List[str]] = [
        "symbol",
        "timestamp",
        "version",
        "p10",
        "p30",
        "p50",
        "p70",
        "p90",
    ]

    @field_validator("version")
    def version_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(["1.4", "1.5"]):
            raise ValueError("must be one of enum values ('1.4', '1.5')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PredictionCreate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PredictionCreate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "symbol": obj.get("symbol"),
                "timestamp": obj.get("timestamp"),
                "version": obj.get("version"),
                "p10": obj.get("p10"),
                "p30": obj.get("p30"),
                "p50": obj.get("p50"),
                "p70": obj.get("p70"),
                "p90": obj.get("p90"),
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# Define package exports
__all__ = [
    "SignalsApi",
    "StatusApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ErrorResponse",
    "Info",
    "Liquidity",
    "PaginatedResponseSignalWithToken",
    "PriceChange",
    "SignalOverviewStats",
    "SignalWithToken",
    "Token",
    "TokenData",
    "TxnCounts",
    "Txns",
    "Volume",
    "Website",
]

# import apis into sdk package
from crypticorn.dex.client.api.signals_api import SignalsApi as SignalsApi
from crypticorn.dex.client.api.status_api import StatusApi as StatusApi

# import ApiClient
from crypticorn.dex.client.api_response import ApiResponse as ApiResponse
from crypticorn.dex.client.api_client import ApiClient as ApiClient
from crypticorn.dex.client.configuration import Configuration as Configuration
from crypticorn.dex.client.exceptions import OpenApiException as OpenApiException
from crypticorn.dex.client.exceptions import ApiTypeError as ApiTypeError
from crypticorn.dex.client.exceptions import ApiValueError as ApiValueError
from crypticorn.dex.client.exceptions import ApiKeyError as ApiKeyError
from crypticorn.dex.client.exceptions import ApiAttributeError as ApiAttributeError
from crypticorn.dex.client.exceptions import ApiException as ApiException

# import models into sdk package
from crypticorn.dex.client.models.error_response import ErrorResponse as ErrorResponse
from crypticorn.dex.client.models.info import Info as Info
from crypticorn.dex.client.models.liquidity import Liquidity as Liquidity
from crypticorn.dex.client.models.paginated_response_signal_with_token import (
    PaginatedResponseSignalWithToken as PaginatedResponseSignalWithToken,
)
from crypticorn.dex.client.models.price_change import PriceChange as PriceChange
from crypticorn.dex.client.models.signal_overview_stats import (
    SignalOverviewStats as SignalOverviewStats,
)
from crypticorn.dex.client.models.signal_with_token import (
    SignalWithToken as SignalWithToken,
)
from crypticorn.dex.client.models.token import Token as Token
from crypticorn.dex.client.models.token_data import TokenData as TokenData
from crypticorn.dex.client.models.txn_counts import TxnCounts as TxnCounts
from crypticorn.dex.client.models.txns import Txns as Txns
from crypticorn.dex.client.models.volume import Volume as Volume
from crypticorn.dex.client.models.website import Website as Website



# coding: utf-8

# flake8: noqa
"""
Indicator API

API for Indicator Data about the crypto market

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from crypticorn.indicator.client.models.economic_news_entry import EconomicNewsEntry
from crypticorn.indicator.client.models.error_response import ErrorResponse
from crypticorn.indicator.client.models.fn_g_entry import FnGEntry
from crypticorn.indicator.client.models.paginated_response_economic_news_entry import (
    PaginatedResponseEconomicNewsEntry,
)
from crypticorn.indicator.client.models.polymarket_prediction import (
    PolymarketPrediction,
)
from crypticorn.indicator.client.models.prediction import Prediction
from crypticorn.indicator.client.models.prediction_create import PredictionCreate



# coding: utf-8

# flake8: noqa

"""
Klines Service API

API for retrieving OHLCV data, funding rates, and symbol information from Binance.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# Define package exports
__all__ = [
    "ChangeInTimeframeApi",
    "FundingRatesApi",
    "OHLCVDataApi",
    "StatusApi",
    "SymbolsApi",
    "UDFApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ChangeInTimeframe",
    "ErrorResponse",
    "FundingRate",
    "FundingRateResponse",
    "OHLCV",
    "SearchSymbol",
    "SymbolGroup",
    "SymbolInfo",
    "SymbolType",
    "UDFConfig",
]

# import apis into sdk package
from crypticorn.klines.client.api.change_in_timeframe_api import (
    ChangeInTimeframeApi as ChangeInTimeframeApi,
)
from crypticorn.klines.client.api.funding_rates_api import (
    FundingRatesApi as FundingRatesApi,
)
from crypticorn.klines.client.api.ohlcv_data_api import OHLCVDataApi as OHLCVDataApi
from crypticorn.klines.client.api.status_api import StatusApi as StatusApi
from crypticorn.klines.client.api.symbols_api import SymbolsApi as SymbolsApi
from crypticorn.klines.client.api.udf_api import UDFApi as UDFApi

# import ApiClient
from crypticorn.klines.client.api_response import ApiResponse as ApiResponse
from crypticorn.klines.client.api_client import ApiClient as ApiClient
from crypticorn.klines.client.configuration import Configuration as Configuration
from crypticorn.klines.client.exceptions import OpenApiException as OpenApiException
from crypticorn.klines.client.exceptions import ApiTypeError as ApiTypeError
from crypticorn.klines.client.exceptions import ApiValueError as ApiValueError
from crypticorn.klines.client.exceptions import ApiKeyError as ApiKeyError
from crypticorn.klines.client.exceptions import ApiAttributeError as ApiAttributeError
from crypticorn.klines.client.exceptions import ApiException as ApiException

# import models into sdk package
from crypticorn.klines.client.models.change_in_timeframe import (
    ChangeInTimeframe as ChangeInTimeframe,
)
from crypticorn.klines.client.models.error_response import (
    ErrorResponse as ErrorResponse,
)
from crypticorn.klines.client.models.funding_rate import FundingRate as FundingRate
from crypticorn.klines.client.models.funding_rate_response import (
    FundingRateResponse as FundingRateResponse,
)
from crypticorn.klines.client.models.ohlcv import OHLCV as OHLCV
from crypticorn.klines.client.models.search_symbol import SearchSymbol as SearchSymbol
from crypticorn.klines.client.models.symbol_group import SymbolGroup as SymbolGroup
from crypticorn.klines.client.models.symbol_info import SymbolInfo as SymbolInfo
from crypticorn.klines.client.models.symbol_type import SymbolType as SymbolType
from crypticorn.klines.client.models.udf_config import UDFConfig as UDFConfig



# flake8: noqa

# import apis into api package
from crypticorn.indicator.client.api.news_api import NewsApi
from crypticorn.indicator.client.api.predictions_api import PredictionsApi
from crypticorn.indicator.client.api.sentiment_api import SentimentApi
from crypticorn.indicator.client.api.status_api import StatusApi



# coding: utf-8

"""
Hive AI API

API for Hive AI model training and evaluation

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Union
from typing import Optional, Set
from typing_extensions import Self


class BinaryEvaluation(BaseModel):
    """
    Pydantic model for binary evaluation
    """  # noqa: E501

    accuracy: Union[StrictFloat, StrictInt] = Field(description="Accuracy")
    roc_auc: Union[StrictFloat, StrictInt] = Field(description="ROC AUC")
    precision: Union[StrictFloat, StrictInt] = Field(description="Precision")
    recall: Union[StrictFloat, StrictInt] = Field(description="Recall")
    f1: Union[StrictFloat, StrictInt] = Field(description="F1 score")
    conf_matrix: List[List[StrictInt]] = Field(description="Confusion matrix")
    __properties: ClassVar[List[str]] = [
        "accuracy",
        "roc_auc",
        "precision",
        "recall",
        "f1",
        "conf_matrix",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BinaryEvaluation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BinaryEvaluation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "accuracy": obj.get("accuracy"),
                "roc_auc": obj.get("roc_auc"),
                "precision": obj.get("precision"),
                "recall": obj.get("recall"),
                "f1": obj.get("f1"),
                "conf_matrix": obj.get("conf_matrix"),
            }
        )
        return _obj



# coding: utf-8

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Set
from typing_extensions import Self


class PriceChange(BaseModel):
    """
    PriceChange
    """  # noqa: E501

    h24: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=0.0, description="24-hour price change percentage"
    )
    h6: Optional[Union[StrictFloat, StrictInt]] = None
    h1: Optional[Union[StrictFloat, StrictInt]] = None
    m5: Optional[Union[StrictFloat, StrictInt]] = None
    __properties: ClassVar[List[str]] = ["h24", "h6", "h1", "m5"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PriceChange from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if h6 (nullable) is None
        # and model_fields_set contains the field
        if self.h6 is None and "h6" in self.model_fields_set:
            _dict["h6"] = None

        # set to None if h1 (nullable) is None
        # and model_fields_set contains the field
        if self.h1 is None and "h1" in self.model_fields_set:
            _dict["h1"] = None

        # set to None if m5 (nullable) is None
        # and model_fields_set contains the field
        if self.m5 is None and "m5" in self.model_fields_set:
            _dict["m5"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PriceChange from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "h24": obj.get("h24") if obj.get("h24") is not None else 0.0,
                "h6": obj.get("h6"),
                "h1": obj.get("h1"),
                "m5": obj.get("m5"),
            }
        )
        return _obj



# coding: utf-8

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from crypticorn.dex.client.models.info import Info
from crypticorn.dex.client.models.liquidity import Liquidity
from crypticorn.dex.client.models.price_change import PriceChange
from crypticorn.dex.client.models.token import Token
from crypticorn.dex.client.models.txns import Txns
from crypticorn.dex.client.models.volume import Volume
from typing import Set
from typing_extensions import Self


class TokenData(BaseModel):
    """
    TokenData
    """  # noqa: E501

    chain_id: StrictStr = Field(description="Blockchain identifier")
    dex_id: StrictStr = Field(description="DEX identifier")
    url: StrictStr = Field(description="DexScreener pair URL")
    pair_address: StrictStr = Field(description="Pair/pool address")
    base_token: Token = Field(description="Base token metadata")
    quote_token: Token = Field(description="Quote token metadata")
    price_native: Union[StrictFloat, StrictInt] = Field(
        description="Token price in native chain currency"
    )
    price_usd: Union[StrictFloat, StrictInt] = Field(description="Token price in USD")
    txns: Txns = Field(
        description="Buy/sell transaction counts over multiple time windows"
    )
    volume: Volume = Field(description="Trading volume over multiple time windows")
    price_change: PriceChange = Field(
        description="Price change percentages over multiple time windows"
    )
    liquidity: Optional[Liquidity] = Field(
        default=None, description="Liquidity breakdown for the pair"
    )
    fdv: Union[StrictFloat, StrictInt] = Field(
        description="Fully diluted valuation in USD"
    )
    market_cap: Union[StrictFloat, StrictInt] = Field(
        description="Market capitalization in USD"
    )
    pair_created_at: StrictInt = Field(
        description="Pair creation timestamp (milliseconds since epoch)"
    )
    info: Optional[Info] = None
    __properties: ClassVar[List[str]] = [
        "chain_id",
        "dex_id",
        "url",
        "pair_address",
        "base_token",
        "quote_token",
        "price_native",
        "price_usd",
        "txns",
        "volume",
        "price_change",
        "liquidity",
        "fdv",
        "market_cap",
        "pair_created_at",
        "info",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TokenData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of base_token
        if self.base_token:
            _dict["base_token"] = self.base_token.to_dict()
        # override the default output from pydantic by calling `to_dict()` of quote_token
        if self.quote_token:
            _dict["quote_token"] = self.quote_token.to_dict()
        # override the default output from pydantic by calling `to_dict()` of txns
        if self.txns:
            _dict["txns"] = self.txns.to_dict()
        # override the default output from pydantic by calling `to_dict()` of volume
        if self.volume:
            _dict["volume"] = self.volume.to_dict()
        # override the default output from pydantic by calling `to_dict()` of price_change
        if self.price_change:
            _dict["price_change"] = self.price_change.to_dict()
        # override the default output from pydantic by calling `to_dict()` of liquidity
        if self.liquidity:
            _dict["liquidity"] = self.liquidity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of info
        if self.info:
            _dict["info"] = self.info.to_dict()
        # set to None if info (nullable) is None
        # and model_fields_set contains the field
        if self.info is None and "info" in self.model_fields_set:
            _dict["info"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TokenData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "chain_id": obj.get("chain_id"),
                "dex_id": obj.get("dex_id"),
                "url": obj.get("url"),
                "pair_address": obj.get("pair_address"),
                "base_token": Token.from_dict(obj["base_token"])
                if obj.get("base_token") is not None
                else None,
                "quote_token": Token.from_dict(obj["quote_token"])
                if obj.get("quote_token") is not None
                else None,
                "price_native": obj.get("price_native"),
                "price_usd": obj.get("price_usd"),
                "txns": Txns.from_dict(obj["txns"])
                if obj.get("txns") is not None
                else None,
                "volume": Volume.from_dict(obj["volume"])
                if obj.get("volume") is not None
                else None,
                "price_change": PriceChange.from_dict(obj["price_change"])
                if obj.get("price_change") is not None
                else None,
                "liquidity": Liquidity.from_dict(obj["liquidity"])
                if obj.get("liquidity") is not None
                else None,
                "fdv": obj.get("fdv"),
                "market_cap": obj.get("market_cap"),
                "pair_created_at": obj.get("pair_created_at"),
                "info": Info.from_dict(obj["info"])
                if obj.get("info") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictFloat,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing import Any, ClassVar, Dict, List, Optional, Union
from crypticorn.dex.client.models.token_data import TokenData
from typing import Set
from typing_extensions import Self


class SignalWithToken(BaseModel):
    """
    Trading signal enriched with comprehensive token metadata and information.
    """  # noqa: E501

    stage: StrictStr = Field(description="Lifecycle stage")
    address: StrictStr = Field(description="Token contract address")
    pair_address: Optional[StrictStr] = None
    chain: StrictStr = Field(description="Chain")
    first_call_time: Optional[datetime] = None
    mc_at_call: Optional[StrictStr] = None
    ath_mc: Optional[StrictStr] = None
    last_x: Optional[StrictInt] = None
    call_id: Optional[StrictStr] = None
    called_at: datetime = Field(description="Time of the first call")
    updated_at: Optional[datetime] = None
    data: Optional[TokenData] = None
    performance: Optional[Union[StrictFloat, StrictInt]]
    __properties: ClassVar[List[str]] = [
        "stage",
        "address",
        "pair_address",
        "chain",
        "first_call_time",
        "mc_at_call",
        "ath_mc",
        "last_x",
        "call_id",
        "called_at",
        "updated_at",
        "data",
        "performance",
    ]

    @field_validator("chain")
    def chain_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(
            ["solana", "ethereum", "bsc", "base", "arbitrum", "polygon", "avalanche"]
        ):
            raise ValueError(
                "must be one of enum values ('solana', 'ethereum', 'bsc', 'base', 'arbitrum', 'polygon', 'avalanche')"
            )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SignalWithToken from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict["data"] = self.data.to_dict()
        # set to None if pair_address (nullable) is None
        # and model_fields_set contains the field
        if self.pair_address is None and "pair_address" in self.model_fields_set:
            _dict["pair_address"] = None

        # set to None if first_call_time (nullable) is None
        # and model_fields_set contains the field
        if self.first_call_time is None and "first_call_time" in self.model_fields_set:
            _dict["first_call_time"] = None

        # set to None if mc_at_call (nullable) is None
        # and model_fields_set contains the field
        if self.mc_at_call is None and "mc_at_call" in self.model_fields_set:
            _dict["mc_at_call"] = None

        # set to None if ath_mc (nullable) is None
        # and model_fields_set contains the field
        if self.ath_mc is None and "ath_mc" in self.model_fields_set:
            _dict["ath_mc"] = None

        # set to None if last_x (nullable) is None
        # and model_fields_set contains the field
        if self.last_x is None and "last_x" in self.model_fields_set:
            _dict["last_x"] = None

        # set to None if call_id (nullable) is None
        # and model_fields_set contains the field
        if self.call_id is None and "call_id" in self.model_fields_set:
            _dict["call_id"] = None

        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict["updated_at"] = None

        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict["data"] = None

        # set to None if performance (nullable) is None
        # and model_fields_set contains the field
        if self.performance is None and "performance" in self.model_fields_set:
            _dict["performance"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SignalWithToken from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "stage": obj.get("stage"),
                "address": obj.get("address"),
                "pair_address": obj.get("pair_address"),
                "chain": obj.get("chain"),
                "first_call_time": obj.get("first_call_time"),
                "mc_at_call": obj.get("mc_at_call"),
                "ath_mc": obj.get("ath_mc"),
                "last_x": obj.get("last_x"),
                "call_id": obj.get("call_id"),
                "called_at": obj.get("called_at"),
                "updated_at": obj.get("updated_at"),
                "data": TokenData.from_dict(obj["data"])
                if obj.get("data") is not None
                else None,
                "performance": obj.get("performance"),
            }
        )
        return _obj



# coding: utf-8

"""
Marketcap Service API

API for retrieving historical marketcap data, available exchanges, and indicators.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from typing import Any, Awaitable, Dict, List, Optional, Tuple, Union

from asgiref.sync import async_to_sync
from pydantic import Field, StrictFloat, StrictInt, StrictStr, validate_call
from typing_extensions import Annotated

from crypticorn.metrics.client.api_client import ApiClient, RequestSerialized
from crypticorn.metrics.client.api_response import ApiResponse
from crypticorn.metrics.client.models.severity import Severity
from crypticorn.metrics.client.rest import RESTResponseType


class LogsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None, is_sync: bool = False) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client
        self.is_sync = is_sync

    @validate_call
    def get_metrics_error_logs(
        self,
        severity: Annotated[
            Optional[Severity], Field(description="Severity level of errors to fetch")
        ] = None,
        start_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="Start timestamp for which to fetch error logs"),
        ] = None,
        end_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="End timestamp for which to fetch error logs"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[List[Dict[str, object]], Awaitable[List[Dict[str, object]]]]:
        """Get Error Logs"""
        if self.is_sync:
            return self._get_metrics_error_logs_sync(
                severity=severity,
                start_timestamp=start_timestamp,
                end_timestamp=end_timestamp,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_metrics_error_logs_async(
                severity=severity,
                start_timestamp=start_timestamp,
                end_timestamp=end_timestamp,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def get_metrics_error_logs_with_http_info(
        self,
        severity: Annotated[
            Optional[Severity], Field(description="Severity level of errors to fetch")
        ] = None,
        start_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="Start timestamp for which to fetch error logs"),
        ] = None,
        end_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="End timestamp for which to fetch error logs"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[
        ApiResponse[List[Dict[str, object]]],
        Awaitable[ApiResponse[List[Dict[str, object]]]],
    ]:
        """Get Error Logs with HTTP info"""
        if self.is_sync:
            return self._get_metrics_error_logs_sync_with_http_info(
                severity=severity,
                start_timestamp=start_timestamp,
                end_timestamp=end_timestamp,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_metrics_error_logs_async_with_http_info(
                severity=severity,
                start_timestamp=start_timestamp,
                end_timestamp=end_timestamp,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    @validate_call
    def get_metrics_error_logs_without_preload_content(
        self,
        severity: Annotated[
            Optional[Severity], Field(description="Severity level of errors to fetch")
        ] = None,
        start_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="Start timestamp for which to fetch error logs"),
        ] = None,
        end_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="End timestamp for which to fetch error logs"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Union[RESTResponseType, Awaitable[RESTResponseType]]:
        """Get Error Logs without preloading content"""
        if self.is_sync:
            return self._get_metrics_error_logs_sync_without_preload_content(
                severity=severity,
                start_timestamp=start_timestamp,
                end_timestamp=end_timestamp,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

        else:
            return self._get_metrics_error_logs_async_without_preload_content(
                severity=severity,
                start_timestamp=start_timestamp,
                end_timestamp=end_timestamp,
                _request_timeout=_request_timeout,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )

    # Private async implementation methods
    @validate_call
    async def _get_metrics_error_logs_async(
        self,
        severity: Annotated[
            Optional[Severity], Field(description="Severity level of errors to fetch")
        ] = None,
        start_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="Start timestamp for which to fetch error logs"),
        ] = None,
        end_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="End timestamp for which to fetch error logs"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Dict[str, object]]:
        """Get Error Logs

        Get error logs with filtering options.

        :param severity: Severity level of errors to fetch
        :type severity: Severity
        :param start_timestamp: Start timestamp for which to fetch error logs
        :type start_timestamp: int
        :param end_timestamp: End timestamp for which to fetch error logs
        :type end_timestamp: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_metrics_error_logs_serialize(
            severity=severity,
            start_timestamp=start_timestamp,
            end_timestamp=end_timestamp,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[Dict[str, object]]",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def _get_metrics_error_logs_async_with_http_info(
        self,
        severity: Annotated[
            Optional[Severity], Field(description="Severity level of errors to fetch")
        ] = None,
        start_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="Start timestamp for which to fetch error logs"),
        ] = None,
        end_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="End timestamp for which to fetch error logs"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Dict[str, object]]]:
        """Get Error Logs

        Get error logs with filtering options.

        :param severity: Severity level of errors to fetch
        :type severity: Severity
        :param start_timestamp: Start timestamp for which to fetch error logs
        :type start_timestamp: int
        :param end_timestamp: End timestamp for which to fetch error logs
        :type end_timestamp: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_metrics_error_logs_serialize(
            severity=severity,
            start_timestamp=start_timestamp,
            end_timestamp=end_timestamp,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[Dict[str, object]]",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data, response_types_map=_response_types_map
        )

    @validate_call
    async def _get_metrics_error_logs_async_without_preload_content(
        self,
        severity: Annotated[
            Optional[Severity], Field(description="Severity level of errors to fetch")
        ] = None,
        start_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="Start timestamp for which to fetch error logs"),
        ] = None,
        end_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="End timestamp for which to fetch error logs"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Error Logs

        Get error logs with filtering options.

        :param severity: Severity level of errors to fetch
        :type severity: Severity
        :param start_timestamp: Start timestamp for which to fetch error logs
        :type start_timestamp: int
        :param end_timestamp: End timestamp for which to fetch error logs
        :type end_timestamp: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_metrics_error_logs_serialize(
            severity=severity,
            start_timestamp=start_timestamp,
            end_timestamp=end_timestamp,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[Dict[str, object]]",
        }

        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data

    # Private sync implementation methods
    @validate_call
    def _get_metrics_error_logs_sync(
        self,
        severity: Annotated[
            Optional[Severity], Field(description="Severity level of errors to fetch")
        ] = None,
        start_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="Start timestamp for which to fetch error logs"),
        ] = None,
        end_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="End timestamp for which to fetch error logs"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Dict[str, object]]:
        """Synchronous version of get_metrics_error_logs"""
        return async_to_sync(self._get_metrics_error_logs_async)(
            severity=severity,
            start_timestamp=start_timestamp,
            end_timestamp=end_timestamp,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _get_metrics_error_logs_sync_with_http_info(
        self,
        severity: Annotated[
            Optional[Severity], Field(description="Severity level of errors to fetch")
        ] = None,
        start_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="Start timestamp for which to fetch error logs"),
        ] = None,
        end_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="End timestamp for which to fetch error logs"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Dict[str, object]]]:
        """Synchronous version of get_metrics_error_logs_with_http_info"""
        return async_to_sync(self._get_metrics_error_logs_async_with_http_info)(
            severity=severity,
            start_timestamp=start_timestamp,
            end_timestamp=end_timestamp,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    @validate_call
    def _get_metrics_error_logs_sync_without_preload_content(
        self,
        severity: Annotated[
            Optional[Severity], Field(description="Severity level of errors to fetch")
        ] = None,
        start_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="Start timestamp for which to fetch error logs"),
        ] = None,
        end_timestamp: Annotated[
            Optional[StrictInt],
            Field(description="End timestamp for which to fetch error logs"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Synchronous version of get_metrics_error_logs_without_preload_content"""
        return async_to_sync(
            self._get_metrics_error_logs_async_without_preload_content
        )(
            severity=severity,
            start_timestamp=start_timestamp,
            end_timestamp=end_timestamp,
            _request_timeout=_request_timeout,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

    def _get_metrics_error_logs_serialize(
        self,
        severity,
        start_timestamp,
        end_timestamp,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if severity is not None:
            _query_params.append(("severity", severity.value))

        if start_timestamp is not None:
            _query_params.append(("start_timestamp", start_timestamp))

        if end_timestamp is not None:
            _query_params.append(("end_timestamp", end_timestamp))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["APIKeyHeader", "HTTPBearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/error_logs",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

# flake8: noqa

"""
Indicator API

API for Indicator Data about the crypto market

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# Define package exports
__all__ = [
    "NewsApi",
    "PredictionsApi",
    "SentimentApi",
    "StatusApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "EconomicNewsEntry",
    "ErrorResponse",
    "FnGEntry",
    "PaginatedResponseEconomicNewsEntry",
    "PolymarketPrediction",
    "Prediction",
    "PredictionCreate",
]

# import apis into sdk package
from crypticorn.indicator.client.api.news_api import NewsApi as NewsApi
from crypticorn.indicator.client.api.predictions_api import (
    PredictionsApi as PredictionsApi,
)
from crypticorn.indicator.client.api.sentiment_api import SentimentApi as SentimentApi
from crypticorn.indicator.client.api.status_api import StatusApi as StatusApi

# import ApiClient
from crypticorn.indicator.client.api_response import ApiResponse as ApiResponse
from crypticorn.indicator.client.api_client import ApiClient as ApiClient
from crypticorn.indicator.client.configuration import Configuration as Configuration
from crypticorn.indicator.client.exceptions import OpenApiException as OpenApiException
from crypticorn.indicator.client.exceptions import ApiTypeError as ApiTypeError
from crypticorn.indicator.client.exceptions import ApiValueError as ApiValueError
from crypticorn.indicator.client.exceptions import ApiKeyError as ApiKeyError
from crypticorn.indicator.client.exceptions import (
    ApiAttributeError as ApiAttributeError,
)
from crypticorn.indicator.client.exceptions import ApiException as ApiException

# import models into sdk package
from crypticorn.indicator.client.models.economic_news_entry import (
    EconomicNewsEntry as EconomicNewsEntry,
)
from crypticorn.indicator.client.models.error_response import (
    ErrorResponse as ErrorResponse,
)
from crypticorn.indicator.client.models.fn_g_entry import FnGEntry as FnGEntry
from crypticorn.indicator.client.models.paginated_response_economic_news_entry import (
    PaginatedResponseEconomicNewsEntry as PaginatedResponseEconomicNewsEntry,
)
from crypticorn.indicator.client.models.polymarket_prediction import (
    PolymarketPrediction as PolymarketPrediction,
)
from crypticorn.indicator.client.models.prediction import Prediction as Prediction
from crypticorn.indicator.client.models.prediction_create import (
    PredictionCreate as PredictionCreate,
)
